Enum Layer
pub enum Layer {
Relative(i16),
Overlay,
OverlayLevel(u8),
}Expand description
The painting layer of an element, controlling what it draws on top of.
Converts from an i16, which becomes a Layer::Relative offset.
Variants
Relative(i16)
Relative layer to the parent’s layer. 0 (the default) keeps the normal stacking order.
Negative values move behind siblings and positive values in front.
Overlay
Adds a big layer jump relative to the parents layer. You may stack multiple overlays on top of each other.
OverlayLevel(u8)
Paint on a specific, numbered overlay level, regardless of the parent’s layer. There are up to 16 levels you can use, anything above will be capped at 16.